# nbcommon

## changelog

- 20200616: support number parameter in nearest api
- 20200529: support FB in osrmapi
- 20200513: FeatureSchema use UTC time
- 20200508: add split_trips
- 20200503: add cleanse GPSPin method to remove abnormal gps pin from list respecting specified threshold
- 20200429: add model module to generate feature vector according to customized schema yaml
- 20200413: add geo.to_poly_filter function. support converting to poly-filter format from single polygon geojson
- 20200413: add geo.poly_to_geojson function. support converting to geojson format from single area poly filter file
- 20200413: add geo.parse_poly function. parsing poly file to array of coords arrays
